Operation

Enum Operation 

#[repr(u32)]
pub enum Operation { Upsert = 0, Add = 1, Replace = 2, Set = 3, Append = 4, Prepend = 5, }

Variants



Upsert = 0

The default storage mode. This constant was added in version 2.6.2 for the sake of maintaining a default storage mode, eliminating the need for simple storage operations to explicitly define operation. Behaviorally it is identical to Set in that it will make the server unconditionally store the item, whether it exists or not.



Add = 1

Will cause the operation to fail if the key already exists in the cluster.



Replace = 2

Will cause the operation to fail unless the key already exists in the cluster.



Set = 3

Unconditionally store the item in the cluster



Append = 4

Rather than setting the contents of the entire document, take the value specified in value and append it to the existing bytes in the value.



Prepend = 5

Like Append, but prepends the new value to the existing value.